@@ -1008,7 +1008,6 @@ CameraUpdatedCallback = Union[
 DeviceManagerEventType = Literal[
     "cameraSelected",
     "cameraDeselected",
-    "cameraUpdated",
 ]
 
 
@@ -1026,8 +1025,6 @@ class DeviceManager(Protocol):
     def on(
         self, event: Literal["cameraDeselected"], listener: CameraDeselectedCallback
     ) -> "DeviceManager": ...
-    @overload
-    def on(self, event: Literal["cameraUpdated"], listener: CameraUpdatedCallback) -> "DeviceManager": ...
 
     @overload
     def once(self, event: Literal["cameraSelected"], listener: CameraSelectedCallback) -> "DeviceManager": ...
@@ -1035,8 +1032,6 @@ class DeviceManager(Protocol):
     def once(
         self, event: Literal["cameraDeselected"], listener: CameraDeselectedCallback
     ) -> "DeviceManager": ...
-    @overload
-    def once(self, event: Literal["cameraUpdated"], listener: CameraUpdatedCallback) -> "DeviceManager": ...
 
     @overload
     def remove_listener(
@@ -1046,10 +1041,6 @@ class DeviceManager(Protocol):
     def remove_listener(
         self, event: Literal["cameraDeselected"], listener: CameraDeselectedCallback
     ) -> "DeviceManager": ...
-    @overload
-    def remove_listener(
-        self, event: Literal["cameraUpdated"], listener: CameraUpdatedCallback
-    ) -> "DeviceManager": ...
 
     def remove_all_listeners(self, event: Optional[DeviceManagerEventType] = None) -> "DeviceManager": ...
 
